@@ -48,6 +48,7 @@ test_that ("bbox", {
   expect_error (bbox_to_string (), "bbox must be provided")
   #expect_error (bbox_to_string ("a"), "bbox must be numeric")
   expect_error (bbox_to_string (1:3), "bbox must contain four elements")
+  expect_error (bbox_to_string (TRUE), "bbox must be numeric")
   expect_message (bbox_to_string (1:5),
                               "only the first four elements of bbox used")
 })
@@ -62,8 +63,21 @@ test_that ('getbb-place_name', {
                    res <- getbb (place_name = "Salzburg")
                    expect_is (res, "matrix")
                    expect_length (res, 4)
+                   res_l <- getbb (place_name = list ("Salzburg"))
+                   expect_identical (res, res_l)
                    res <- getbb (place_name = "Salzburg", format_out = "string")
                    expect_is (res, "character")
+
+                   expect_silent (res <- getbb (place_name = "Salzburg",
+                                                featuretype = "state"))
+                   expect_output (res <- getbb (place_name = "Salzburg",
+                                                silent = FALSE))
+                   expect_silent (res <- getbb (place_name = "Salzburg",
+                                                format_out = "data.frame"))
+                   expect_is (res, "data.frame")
+                   expect_error (res <- getbb (place_name = "Salzburg",
+                                               format_out = "no format"),
+                                 "format_out not recognised")
                }
           })
 
@@ -77,7 +91,13 @@ test_that ('getbb-polygon', {
                    res <- getbb (place_name = "Salzburg", format_out = "polygon")
                    expect_is (res, "list")
                    expect_true (all (lapply (res, nrow) > 2))
-                   expect_true (all (lapply (res, class) == "matrix"))
+                   expect_true (all (vapply (res, function (i)
+                                             methods::is (i, "matrix"),
+                                             logical (1))))
+
+                   expect_silent (res_str <- bbox_to_string (res [[1]]))
+                   expect_is (res_str, "character")
+
                    res <- getbb (place_name = "Salzburg", format_out = "sf_polygon")
                    expect_is (res, "sf")
                    expect_is (res$geometry, "sfc_POLYGON")
